/* IE 6 & 7 */

/* Proper fixed width for dashboard in IE6 */

.dashboard #content {
    *width: 768px;
}

.dashboard #content-main {
    *width: 535px;
}

/* IE 6 ONLY */

/* Keep header from flowing off the page */

#container {
    _position: static;
}

/* Put the right sidebars back on the page */

.colMS #content-related {
    _margin-right: 0;
    _margin-left: 10px;
    _position: static;
}

/* Put the left sidebars back on the page */

.colSM #content-related {
    _margin-right: 10px;
    _margin-left: -115px;
    _position: static;
}

.form-row {
    _height: 1%;
}

/* Fix right margin for changelist filters in IE6 */

#changelist-filter ul {
    _margin-right: -10px;
}

/* IE ignores min-height, but treats height as if it were min-height */

.change-list .filtered {
    _height: 400px;
}

/* IE doesn't know alpha transparency in PNGs */

.inline-deletelink {
    background: transparent url(../img/inline-delete-8bit.png) no-repeat;
}

/* IE7 doesn't support inline-block */
.change-list ul.toplinks li {
    zoom: 1;
    *display: inline;
}